simple_appstore_screenshot library

Classes

SimpleScreenShot
A Widget to create the appstore screenshot easy Add callback to take screenshot Add description if you want to display some word in the screenshot